@@ -2,6 +2,9 @@
 
 pub mod sequence;
 
+pub use crate::sequence::builder::SequenceBuilder;
+pub use sequence::renderer::SeqRendererBuilder;
+
 #[derive(Debug, Eq, PartialEq)]
 pub enum SequenceError {
 	OutOfRange,
@@ -18,5 +21,3 @@ pub enum SequenceError {
 }
 
 const LETTERS: u64 = 25;
-const A: u32  = 0;
-const Z: u32 = 25;
