@@ -9,16 +9,6 @@ pub enum RenderDisplay {
 	Numeric,
 }
 
-impl RenderDisplay {
-	fn pad_char(self) -> char {
-		match self {
-			Self::Upper   => 'A',
-			Self::Lower   => 'a',
-			Self::Numeric => '0',
-		}
-	}
-}
-
 impl Default for RenderDisplay {
 	fn default() -> Self { RenderDisplay::Numeric }
 }
@@ -76,7 +66,7 @@ impl SeqRenderer {
 	pub fn display(self) -> RenderDisplay { self.display }
 
 	/// ```rust
-	/// use letter_sequence::sequence::renderer::SeqRendererBuilder;
+	/// use letter_sequence::SeqRendererBuilder;
 	///
 	/// let upper = SeqRendererBuilder::default().upper().build().unwrap();
 	/// assert_eq!(upper.render(0).unwrap(), "A");
@@ -165,6 +155,8 @@ impl SeqRendererBuilder {
 /// ```
 pub fn max_alpha(chars: u8) -> u64 {
 	const BASE : u64 = 26;
+	const Z: u32 = 25;
+
 	let mut max: u64 = 0;
 	for x in 0..chars {
 		max += (1 + Z) as u64 * BASE.pow(x as u32)
